@@ -1,6 +1,5 @@
     Mac OS X            	   2                                               ATTR w
-         +                     	  com.apple.acl.text         "  com.macromates.caret !#acl 1
- {
+         "                     "  com.macromates.caret {
     column = 22;
     line = 4;
 }
\ No newline at end of file
